@@ -24,11 +24,12 @@ import re
 import urllib2
 import time
 import subprocess
-from optparse import OptionParser
+from argparse import ArgumentParser
 import traceback
 import HTMLParser
 from distutils.version import LooseVersion
 import logging
+import copy
 
 import common
 import metadata
@@ -43,10 +44,10 @@ def check_http(app):
 
     try:
 
-        if 'Update Check Data' not in app:
+        if not app.UpdateCheckData:
             raise FDroidException('Missing Update Check Data')
 
-        urlcode, codeex, urlver, verex = app['Update Check Data'].split('|')
+        urlcode, codeex, urlver, verex = app.UpdateCheckData.split('|')
 
         vercode = "99999999"
         if len(urlcode) > 0:
@@ -76,7 +77,7 @@ def check_http(app):
         return (version, vercode)
 
     except FDroidException:
-        msg = "Could not complete http check for app {0} due to unknown error: {1}".format(app['id'], traceback.format_exc())
+        msg = "Could not complete http check for app {0} due to unknown error: {1}".format(app.id, traceback.format_exc())
         return (None, msg)
 
 
@@ -90,31 +91,30 @@ def check_tags(app, pattern):
 
     try:
 
-        appid = app['Update Check Name'] or app['id']
-        if app['Repo Type'] == 'srclib':
-            build_dir = os.path.join('build', 'srclib', app['Repo'])
-            repotype = common.getsrclibvcs(app['Repo'])
+        if app.RepoType == 'srclib':
+            build_dir = os.path.join('build', 'srclib', app.Repo)
+            repotype = common.getsrclibvcs(app.Repo)
         else:
-            build_dir = os.path.join('build/', app['id'])
-            repotype = app['Repo Type']
+            build_dir = os.path.join('build', app.id)
+            repotype = app.RepoType
 
         if repotype not in ('git', 'git-svn', 'hg', 'bzr'):
             return (None, 'Tags update mode only works for git, hg, bzr and git-svn repositories currently', None)
 
-        if repotype == 'git-svn' and ';' not in app['Repo']:
+        if repotype == 'git-svn' and ';' not in app.Repo:
             return (None, 'Tags update mode used in git-svn, but the repo was not set up with tags', None)
 
         # Set up vcs interface and make sure we have the latest code...
-        vcs = common.getvcs(app['Repo Type'], app['Repo'], build_dir)
+        vcs = common.getvcs(app.RepoType, app.Repo, build_dir)
 
         vcs.gotorevision(None)
 
-        flavours = []
-        if len(app['builds']) > 0:
-            if app['builds'][-1]['subdir']:
-                build_dir = os.path.join(build_dir, app['builds'][-1]['subdir'])
-            if app['builds'][-1]['gradle']:
-                flavours = app['builds'][-1]['gradle']
+        last_build = metadata.Build()
+        if len(app.builds) > 0:
+            last_build = app.builds[-1]
+
+        if last_build.submodules:
+            vcs.initsubmodules()
 
         hpak = None
         htag = None
@@ -122,11 +122,18 @@ def check_tags(app, pattern):
         hcode = "0"
 
         tags = vcs.gettags()
+        if not tags:
+            return (None, "No tags found", None)
+
+        logging.debug("All tags: " + ','.join(tags))
         if pattern:
             pat = re.compile(pattern)
             tags = [tag for tag in tags if pat.match(tag)]
+            if not tags:
+                return (None, "No matching tags found", None)
+            logging.debug("Matching tags: " + ','.join(tags))
 
-        if repotype in ('git',):
+        if len(tags) > 5 and repotype in ('git',):
             tags = vcs.latesttags(tags, 5)
             logging.debug("Latest tags: " + ','.join(tags))
 
@@ -134,20 +141,21 @@ def check_tags(app, pattern):
             logging.debug("Check tag: '{0}'".format(tag))
             vcs.gotorevision(tag)
 
-            # Only process tags where the manifest exists...
-            paths = common.manifest_paths(build_dir, flavours)
-            version, vercode, package = \
-                common.parse_androidmanifests(paths, app['Update Check Ignore'])
-            if not package or package != appid or not version or not vercode:
-                continue
-
-            logging.debug("Manifest exists. Found version {0} ({1})"
-                          .format(version, vercode))
-            if int(vercode) > int(hcode):
-                hpak = package
-                htag = tag
-                hcode = str(int(vercode))
-                hver = version
+            for subdir in possible_subdirs(app):
+                if subdir == '.':
+                    root_dir = build_dir
+                else:
+                    root_dir = os.path.join(build_dir, subdir)
+                paths = common.manifest_paths(root_dir, last_build.gradle)
+                version, vercode, package = common.parse_androidmanifests(paths, app)
+                if vercode:
+                    logging.debug("Manifest exists in subdir '{0}'. Found version {1} ({2})"
+                                  .format(subdir, version, vercode))
+                    if int(vercode) > int(hcode):
+                        hpak = package
+                        htag = tag
+                        hcode = str(int(vercode))
+                        hver = version
 
         if not hpak:
             return (None, "Couldn't find package ID", None)
@@ -156,10 +164,10 @@ def check_tags(app, pattern):
         return (None, "Couldn't find any version information", None)
 
     except VCSException as vcse:
-        msg = "VCS error while scanning app {0}: {1}".format(app['id'], vcse)
+        msg = "VCS error while scanning app {0}: {1}".format(app.id, vcse)
         return (None, msg, None)
     except Exception:
-        msg = "Could not scan app {0} due to unknown error: {1}".format(app['id'], traceback.format_exc())
+        msg = "Could not scan app {0} due to unknown error: {1}".format(app.id, traceback.format_exc())
         return (None, msg, None)
 
 
@@ -173,16 +181,15 @@ def check_repomanifest(app, branch=None):
 
     try:
 
-        appid = app['Update Check Name'] or app['id']
-        if app['Repo Type'] == 'srclib':
-            build_dir = os.path.join('build', 'srclib', app['Repo'])
-            repotype = common.getsrclibvcs(app['Repo'])
+        if app.RepoType == 'srclib':
+            build_dir = os.path.join('build', 'srclib', app.Repo)
+            repotype = common.getsrclibvcs(app.Repo)
         else:
-            build_dir = os.path.join('build/', app['id'])
-            repotype = app['Repo Type']
+            build_dir = os.path.join('build', app.id)
+            repotype = app.RepoType
 
         # Set up vcs interface and make sure we have the latest code...
-        vcs = common.getvcs(app['Repo Type'], app['Repo'], build_dir)
+        vcs = common.getvcs(app.RepoType, app.Repo, build_dir)
 
         if repotype == 'git':
             if branch:
@@ -195,71 +202,70 @@ def check_repomanifest(app, branch=None):
         elif repotype == 'bzr':
             vcs.gotorevision(None)
 
-        flavours = []
-        if len(app['builds']) > 0:
-            if app['builds'][-1]['subdir']:
-                build_dir = os.path.join(build_dir, app['builds'][-1]['subdir'])
-            if app['builds'][-1]['gradle']:
-                flavours = app['builds'][-1]['gradle']
+        last_build = metadata.Build()
+        if len(app.builds) > 0:
+            last_build = app.builds[-1]
 
-        if not os.path.isdir(build_dir):
-            return (None, "Subdir '" + app['builds'][-1]['subdir'] + "'is not a valid directory")
+        if last_build.submodules:
+            vcs.initsubmodules()
 
-        paths = common.manifest_paths(build_dir, flavours)
+        hpak = None
+        hver = None
+        hcode = "0"
+        for subdir in possible_subdirs(app):
+            if subdir == '.':
+                root_dir = build_dir
+            else:
+                root_dir = os.path.join(build_dir, subdir)
+            paths = common.manifest_paths(root_dir, last_build.gradle)
+            version, vercode, package = common.parse_androidmanifests(paths, app)
+            if vercode:
+                logging.debug("Manifest exists in subdir '{0}'. Found version {1} ({2})"
+                              .format(subdir, version, vercode))
+                if int(vercode) > int(hcode):
+                    hpak = package
+                    hcode = str(int(vercode))
+                    hver = version
 
-        version, vercode, package = \
-            common.parse_androidmanifests(paths, app['Update Check Ignore'])
-        if not package:
+        if not hpak:
             return (None, "Couldn't find package ID")
-        if package != appid:
-            return (None, "Package ID mismatch - expected {0}, got {1}"
-                    .format(appid, package))
-        if not version:
-            return (None, "Couldn't find latest version name")
-        if not vercode:
-            if "Ignore" == version:
-                return (None, "Latest version is ignored")
-            return (None, "Couldn't find latest version code")
-
-        vercode = str(int(vercode))
-
-        logging.debug("Manifest exists. Found version {0} ({1})".format(version, vercode))
-
-        return (version, vercode)
+        if hver:
+            return (hver, hcode)
+        return (None, "Couldn't find any version information")
 
     except VCSException as vcse:
-        msg = "VCS error while scanning app {0}: {1}".format(app['id'], vcse)
+        msg = "VCS error while scanning app {0}: {1}".format(app.id, vcse)
         return (None, msg)
     except Exception:
-        msg = "Could not scan app {0} due to unknown error: {1}".format(app['id'], traceback.format_exc())
+        msg = "Could not scan app {0} due to unknown error: {1}".format(app.id, traceback.format_exc())
         return (None, msg)
 
 
 def check_repotrunk(app, branch=None):
 
     try:
-        if app['Repo Type'] == 'srclib':
-            build_dir = os.path.join('build', 'srclib', app['Repo'])
-            repotype = common.getsrclibvcs(app['Repo'])
+        if app.RepoType == 'srclib':
+            build_dir = os.path.join('build', 'srclib', app.Repo)
+            repotype = common.getsrclibvcs(app.Repo)
         else:
-            build_dir = os.path.join('build/', app['id'])
-            repotype = app['Repo Type']
+            build_dir = os.path.join('build', app.id)
+            repotype = app.RepoType
 
         if repotype not in ('git-svn', ):
             return (None, 'RepoTrunk update mode only makes sense in git-svn repositories')
 
         # Set up vcs interface and make sure we have the latest code...
-        vcs = common.getvcs(app['Repo Type'], app['Repo'], build_dir)
+        vcs = common.getvcs(app.RepoType, app.Repo, build_dir)
 
         vcs.gotorevision(None)
 
         ref = vcs.getref()
         return (ref, ref)
     except VCSException as vcse:
-        msg = "VCS error while scanning app {0}: {1}".format(app['id'], vcse)
+        msg = "VCS error while scanning app {0}: {1}".format(app.id, vcse)
         return (None, msg)
     except Exception:
-        msg = "Could not scan app {0} due to unknown error: {1}".format(app['id'], traceback.format_exc())
+        msg = "Could not scan app {0} due to unknown error: {1}".format(app.id, traceback.format_exc())
         return (None, msg)
 
 
@@ -268,15 +274,15 @@ def check_repotrunk(app, branch=None):
 # the details of the current version.
 def check_gplay(app):
     time.sleep(15)
-    url = 'https://play.google.com/store/apps/details?id=' + app['id']
+    url = 'https://play.google.com/store/apps/details?id=' + app.id
     headers = {'User-Agent': 'Mozilla/5.0 (X11; Linux i686; rv:18.0) Gecko/20100101 Firefox/18.0'}
     req = urllib2.Request(url, None, headers)
     try:
         resp = urllib2.urlopen(req, None, 20)
         page = resp.read()
-    except urllib2.HTTPError, e:
+    except urllib2.HTTPError as e:
         return (None, str(e.code))
-    except Exception, e:
+    except Exception as e:
         return (None, 'Failed:' + str(e))
 
     version = None
@@ -305,62 +311,61 @@ def dirs_with_manifest(startdir):
 
 # Tries to find a new subdir starting from the root build_dir. Returns said
 # subdir relative to the build dir if found, None otherwise.
-def check_changed_subdir(app):
+def possible_subdirs(app):
 
-    appid = app['Update Check Name'] or app['id']
-    if app['Repo Type'] == 'srclib':
-        build_dir = os.path.join('build', 'srclib', app['Repo'])
+    if app.RepoType == 'srclib':
+        build_dir = os.path.join('build', 'srclib', app.Repo)
     else:
-        build_dir = os.path.join('build/', app['id'])
+        build_dir = os.path.join('build', app.id)
 
-    if not os.path.isdir(build_dir):
-        return None
-
-    flavours = []
-    if len(app['builds']) > 0 and app['builds'][-1]['gradle']:
-        flavours = app['builds'][-1]['gradle']
+    last_build = metadata.Build()
+    if len(app.builds) > 0:
+        last_build = app.builds[-1]
 
     for d in dirs_with_manifest(build_dir):
-        logging.debug("Trying possible dir %s." % d)
-        m_paths = common.manifest_paths(d, flavours)
-        package = common.parse_androidmanifests(m_paths, app['Update Check Ignore'])[2]
-        if package and package == appid:
-            logging.debug("Manifest exists in possible dir %s." % d)
-            return os.path.relpath(d, build_dir)
-
-    return None
+        m_paths = common.manifest_paths(d, last_build.gradle)
+        package = common.parse_androidmanifests(m_paths, app)[2]
+        if package is not None:
+            subdir = os.path.relpath(d, build_dir)
+            logging.debug("Adding possible subdir %s" % subdir)
+            yield subdir
 
 
 def fetch_autoname(app, tag):
 
-    if not app["Repo Type"] or app['Update Check Mode'] in ('None', 'Static'):
+    if not app.RepoType or app.UpdateCheckMode in ('None', 'Static'):
         return None
 
-    if app['Repo Type'] == 'srclib':
-        app_dir = os.path.join('build', 'srclib', app['Repo'])
+    if app.RepoType == 'srclib':
+        build_dir = os.path.join('build', 'srclib', app.Repo)
     else:
-        app_dir = os.path.join('build/', app['id'])
+        build_dir = os.path.join('build', app.id)
 
     try:
-        vcs = common.getvcs(app["Repo Type"], app["Repo"], app_dir)
+        vcs = common.getvcs(app.RepoType, app.Repo, build_dir)
         vcs.gotorevision(tag)
     except VCSException:
         return None
 
-    flavours = []
-    if len(app['builds']) > 0:
-        if app['builds'][-1]['subdir']:
-            app_dir = os.path.join(app_dir, app['builds'][-1]['subdir'])
-        if app['builds'][-1]['gradle']:
-            flavours = app['builds'][-1]['gradle']
+    last_build = metadata.Build()
+    if len(app.builds) > 0:
+        last_build = app.builds[-1]
 
-    logging.debug("...fetch auto name from " + app_dir)
-    new_name = common.fetch_real_name(app_dir, flavours)
+    logging.debug("...fetch auto name from " + build_dir)
+    new_name = None
+    for subdir in possible_subdirs(app):
+        if subdir == '.':
+            root_dir = build_dir
+        else:
+            root_dir = os.path.join(build_dir, subdir)
+        new_name = common.fetch_real_name(root_dir, last_build.gradle)
+        if new_name is not None:
+            break
     commitmsg = None
     if new_name:
         logging.debug("...got autoname '" + new_name + "'")
-        if new_name != app['Auto Name']:
-            app['Auto Name'] = new_name
+        if new_name != app.AutoName:
+            app.AutoName = new_name
             if not commitmsg:
                 commitmsg = "Set autoname of {0}".format(common.getappname(app))
     else:
@@ -379,10 +384,12 @@ def checkupdates_app(app, first=True):
     msg = None
     vercode = None
     noverok = False
-    mode = app['Update Check Mode']
+    mode = app.UpdateCheckMode
     if mode.startswith('Tags'):
         pattern = mode[5:] if len(mode) > 4 else None
         (version, vercode, tag) = check_tags(app, pattern)
+        if version == 'Unknown':
+            version = tag
         msg = vercode
     elif mode == 'RepoManifest':
         (version, vercode) = check_repomanifest(app)
@@ -405,37 +412,30 @@ def checkupdates_app(app, first=True):
         version = None
         msg = 'Invalid update check method'
 
-    if first and version is None and vercode == "Couldn't find package ID":
-        logging.warn("Couldn't find any version information. Looking for a subdir change...")
-        new_subdir = check_changed_subdir(app)
-        if new_subdir is None:
-            logging.warn("Couldn't find any new subdir.")
-        else:
-            logging.warn("Trying a new subdir: %s" % new_subdir)
-            new_build = {}
-            metadata.fill_build_defaults(new_build)
-            new_build['version'] = "Ignore"
-            new_build['vercode'] = "-1"
-            new_build['subdir'] = new_subdir
-            app['builds'].append(new_build)
-            return checkupdates_app(app, first=False)
-
-    if version and vercode and app['Vercode Operation']:
-        op = app['Vercode Operation'].replace("%c", str(int(vercode)))
+    if version and vercode and app.VercodeOperation:
+        oldvercode = str(int(vercode))
+        op = app.VercodeOperation.replace("%c", oldvercode)
         vercode = str(eval(op))
+        logging.debug("Applied vercode operation: %s -> %s" % (oldvercode, vercode))
+
+    if version and any(version.startswith(s) for s in [
+            '${',  # Gradle variable names
+            '@string/',  # Strings we could not resolve
+            ]):
+        version = "Unknown"
 
     updating = False
     if version is None:
-        logmsg = "...{0} : {1}".format(app['id'], msg)
+        logmsg = "...{0} : {1}".format(app.id, msg)
         if noverok:
             logging.info(logmsg)
         else:
             logging.warn(logmsg)
-    elif vercode == app['Current Version Code']:
+    elif vercode == app.CurrentVersionCode:
         logging.info("...up to date")
     else:
-        app['Current Version'] = version
-        app['Current Version Code'] = str(int(vercode))
+        app.CurrentVersion = version
+        app.CurrentVersionCode = str(int(vercode))
         updating = True
 
     commitmsg = fetch_autoname(app, tag)
@@ -447,7 +447,7 @@ def checkupdates_app(app, first=True):
         commitmsg = 'Update CV of %s to %s' % (name, ver)
 
     if options.auto:
-        mode = app['Auto Update Mode']
+        mode = app.AutoUpdateMode
         if mode in ('None', 'Static'):
             pass
         elif mode.startswith('Version '):
@@ -461,39 +461,41 @@ def checkupdates_app(app, first=True):
                 suffix = ''
             gotcur = False
             latest = None
-            for build in app['builds']:
-                if build['vercode'] == app['Current Version Code']:
+            for build in app.builds:
+                if int(build.vercode) >= int(app.CurrentVersionCode):
                     gotcur = True
-                if not latest or int(build['vercode']) > int(latest['vercode']):
+                if not latest or int(build.vercode) > int(latest.vercode):
                     latest = build
 
+            if int(latest.vercode) > int(app.CurrentVersionCode):
+                logging.info("Refusing to auto update, since the latest build is newer")
+
             if not gotcur:
-                newbuild = latest.copy()
-                if 'origlines' in newbuild:
-                    del newbuild['origlines']
-                newbuild['disable'] = False
-                newbuild['vercode'] = app['Current Version Code']
-                newbuild['version'] = app['Current Version'] + suffix
-                logging.info("...auto-generating build for " + newbuild['version'])
-                commit = pattern.replace('%v', newbuild['version'])
-                commit = commit.replace('%c', newbuild['vercode'])
-                newbuild['commit'] = commit
-                app['builds'].append(newbuild)
+                newbuild = copy.deepcopy(latest)
+                newbuild.disable = False
+                newbuild.vercode = app.CurrentVersionCode
+                newbuild.version = app.CurrentVersion + suffix
+                logging.info("...auto-generating build for " + newbuild.version)
+                commit = pattern.replace('%v', newbuild.version)
+                commit = commit.replace('%c', newbuild.vercode)
+                newbuild.commit = commit
+                app.builds.append(newbuild)
                 name = common.getappname(app)
                 ver = common.getcvname(app)
                 commitmsg = "Update %s to %s" % (name, ver)
         else:
-            logging.warn('Invalid auto update mode "' + mode + '" on ' + app['id'])
+            logging.warn('Invalid auto update mode "' + mode + '" on ' + app.id)
 
     if commitmsg:
-        metafile = os.path.join('metadata', app['id'] + '.txt')
-        metadata.write_metadata(metafile, app)
+        metadatapath = os.path.join('metadata', app.id + '.txt')
+        with open(metadatapath, 'w') as f:
+            metadata.write_metadata('txt', f, app)
         if options.commit:
-            logging.info("Commiting update for " + metafile)
+            logging.info("Commiting update for " + metadatapath)
             gitcmd = ["git", "commit", "-m", commitmsg]
             if 'auto_author' in config:
                 gitcmd.extend(['--author', config['auto_author']])
-            gitcmd.extend(["--", metafile])
+            gitcmd.extend(["--", metadatapath])
             if subprocess.call(gitcmd) != 0:
                 logging.error("Git commit failed")
                 sys.exit(1)
@@ -508,27 +510,25 @@ def main():
     global config, options
 
     # Parse command line...
-    parser = OptionParser(usage="Usage: %prog [options] [APPID [APPID ...]]")
-    parser.add_option("-v", "--verbose", action="store_true", default=False,
-                      help="Spew out even more information than normal")
-    parser.add_option("-q", "--quiet", action="store_true", default=False,
-                      help="Restrict output to warnings and errors")
-    parser.add_option("--auto", action="store_true", default=False,
-                      help="Process auto-updates")
-    parser.add_option("--autoonly", action="store_true", default=False,
-                      help="Only process apps with auto-updates")
-    parser.add_option("--commit", action="store_true", default=False,
-                      help="Commit changes")
-    parser.add_option("--gplay", action="store_true", default=False,
-                      help="Only print differences with the Play Store")
-    (options, args) = parser.parse_args()
+    parser = ArgumentParser(usage="%(prog)s [options] [APPID [APPID ...]]")
+    common.setup_global_opts(parser)
+    parser.add_argument("appid", nargs='*', help="app-id to check for updates")
+    parser.add_argument("--auto", action="store_true", default=False,
+                        help="Process auto-updates")
+    parser.add_argument("--autoonly", action="store_true", default=False,
+                        help="Only process apps with auto-updates")
+    parser.add_argument("--commit", action="store_true", default=False,
+                        help="Commit changes")
+    parser.add_argument("--gplay", action="store_true", default=False,
+                        help="Only print differences with the Play Store")
+    options = parser.parse_args()
 
     config = common.read_config(options)
 
     # Get all apps...
     allapps = metadata.read_metadata()
 
-    apps = common.read_app_args(args, allapps, False)
+    apps = common.read_app_args(options.appid, allapps, False)
 
     if options.gplay:
         for app in apps:
@@ -539,7 +539,7 @@ def main():
                 else:
                     logging.info("{0} encountered a problem: {1}".format(common.getappname(app), reason))
             if version is not None:
-                stored = app['Current Version']
+                stored = app.CurrentVersion
                 if not stored:
                     logging.info("{0} has no Current Version but has version {1} on the Play Store"
                                  .format(common.getappname(app), version))
@@ -557,7 +557,7 @@ def main():
 
     for appid, app in apps.iteritems():
 
-        if options.autoonly and app['Auto Update Mode'] in ('None', 'Static'):
+        if options.autoonly and app.AutoUpdateMode in ('None', 'Static'):
             logging.debug("Nothing to do for {0}...".format(appid))
             continue
 
