@@ -25,7 +25,7 @@ import re
 import shutil
 import socket
 import sys
-from optparse import OptionParser
+from argparse import ArgumentParser
 import logging
 
 import common
@@ -50,36 +50,33 @@ def main():
     global options, config
 
     # Parse command line...
-    parser = OptionParser()
-    parser.add_option("-v", "--verbose", action="store_true", default=False,
-                      help="Spew out even more information than normal")
-    parser.add_option("-q", "--quiet", action="store_true", default=False,
-                      help="Restrict output to warnings and errors")
-    parser.add_option("-d", "--distinguished-name", default=None,
-                      help="X.509 'Distiguished Name' used when generating keys")
-    parser.add_option("--keystore", default=None,
-                      help="Path to the keystore for the repo signing key")
-    parser.add_option("--repo-keyalias", default=None,
-                      help="Alias of the repo signing key in the keystore")
-    parser.add_option("--android-home", default=None,
-                      help="Path to the Android SDK (sometimes set in ANDROID_HOME)")
-    parser.add_option("--no-prompt", action="store_true", default=False,
-                      help="Do not prompt for Android SDK path, just fail")
-    (options, args) = parser.parse_args()
+    parser = ArgumentParser()
+    common.setup_global_opts(parser)
+    parser.add_argument("-d", "--distinguished-name", default=None,
+                        help="X.509 'Distiguished Name' used when generating keys")
+    parser.add_argument("--keystore", default=None,
+                        help="Path to the keystore for the repo signing key")
+    parser.add_argument("--repo-keyalias", default=None,
+                        help="Alias of the repo signing key in the keystore")
+    parser.add_argument("--android-home", default=None,
+                        help="Path to the Android SDK (sometimes set in ANDROID_HOME)")
+    parser.add_argument("--no-prompt", action="store_true", default=False,
+                        help="Do not prompt for Android SDK path, just fail")
+    options = parser.parse_args()
 
     # find root install prefix
     tmp = os.path.dirname(sys.argv[0])
+    examplesdir = None
     if os.path.basename(tmp) == 'bin':
-        prefix = None
         egg_link = os.path.join(tmp, '..', 'local/lib/python2.7/site-packages/fdroidserver.egg-link')
         if os.path.exists(egg_link):
             # installed from local git repo
             examplesdir = os.path.join(open(egg_link).readline().rstrip(), 'examples')
         else:
-            prefix = os.path.dirname(os.path.dirname(__file__))  # use .egg layout
-            if not prefix.endswith('.egg'):  # use UNIX layout
-                prefix = os.path.dirname(tmp)
-            examplesdir = prefix + '/share/doc/fdroidserver/examples'
+            # try .egg layout
+            examplesdir = os.path.dirname(os.path.dirname(__file__)) + '/share/doc/fdroidserver/examples'
+            if not os.path.exists(examplesdir):  # use UNIX layout
+                examplesdir = os.path.dirname(tmp) + '/share/doc/fdroidserver/examples'
     else:
         # we're running straight out of the git repo
         prefix = os.path.normpath(os.path.join(os.path.dirname(__file__), '..'))
