@@ -17,14 +17,15 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from optparse import OptionParser
+from argparse import ArgumentParser
 import common
 import metadata
 
 
 def main():
 
-    parser = OptionParser(usage="Usage: %prog")
+    parser = ArgumentParser(usage="%(prog)s")
+    common.setup_global_opts(parser)
     parser.parse_args()
     common.read_config(None)
 
