@@ -20,10 +20,11 @@
 import sys
 import os
 import glob
-from optparse import OptionParser
+from argparse import ArgumentParser
 import logging
 
 import common
+import net
 from common import FDroidException
 
 options = None
@@ -35,12 +36,10 @@ def main():
     global options, config
 
     # Parse command line...
-    parser = OptionParser(usage="Usage: %prog [options] [APPID[:VERCODE] [APPID[:VERCODE] ...]]")
-    parser.add_option("-v", "--verbose", action="store_true", default=False,
-                      help="Spew out even more information than normal")
-    parser.add_option("-q", "--quiet", action="store_true", default=False,
-                      help="Restrict output to warnings and errors")
-    (options, args) = parser.parse_args()
+    parser = ArgumentParser(usage="%(prog)s [options] [APPID[:VERCODE] [APPID[:VERCODE] ...]]")
+    common.setup_global_opts(parser)
+    parser.add_argument("appid", nargs='*', help="app-id with optional versioncode in the form APPID[:VERCODE]")
+    options = parser.parse_args()
 
     config = common.read_config(options)
 
@@ -57,7 +56,7 @@ def main():
     verified = 0
     notverified = 0
 
-    vercodes = common.read_pkg_args(args, True)
+    vercodes = common.read_pkg_args(options.appid, True)
 
     for apkfile in sorted(glob.glob(os.path.join(unsigned_dir, '*.apk'))):
 
@@ -78,7 +77,7 @@ def main():
                 os.remove(remoteapk)
             url = 'https://f-droid.org/repo/' + apkfilename
             logging.info("...retrieving " + url)
-            common.download_file(url, dldir=tmp_dir)
+            net.download_file(url, dldir=tmp_dir)
 
             compare_result = common.compare_apks(
                 os.path.join(unsigned_dir, apkfilename),
@@ -90,7 +89,7 @@ def main():
             logging.info("...successfully verified")
             verified += 1
 
-        except FDroidException, e:
+        except FDroidException as e:
             logging.info("...NOT verified - {0}".format(e))
             notverified += 1
 
