@@ -194,6 +194,8 @@ class FDroid
 			return 'https://www.gnu.org/licenses/license-list.html#X11License';
 		case 'NewBSD':
 			return 'https://www.gnu.org/licenses/license-list.html#ModifiedBSD';
+		case 'FreeBSD':
+			return 'https://www.gnu.org/licenses/license-list.html#FreeBSD';
 		case 'BSD':
 			return 'https://www.gnu.org/licenses/license-list.html#OriginalBSD';
 		case 'GPLv3':
@@ -207,7 +209,6 @@ class FDroid
 			return 'https://www.gnu.org/licenses/license-list.html#AGPLv3.0';
 		case 'LGPL':
 			return 'https://www.gnu.org/licenses/license-list.html#LGPL';
-		case 'LGPL':
 		case 'LGPLv3':
 			return 'https://www.gnu.org/licenses/license-list.html#LGPLv3';
 		case 'LGPLv2.1':
@@ -216,12 +217,37 @@ class FDroid
 			return 'https://www.gnu.org/licenses/license-list.html#apache2';
 		case 'WTFPL':
 			return 'https://www.gnu.org/licenses/license-list.html#WTFPL';
+		case 'ISC':
+			return 'https://www.gnu.org/licenses/license-list.html#ISC';
+		case 'Expat':
+			return 'https://www.gnu.org/licenses/license-list.html#Expat';
+		case 'Artistic2':
+			return 'https://www.gnu.org/licenses/license-list.html#ArtisticLicense2';
+		case 'CC0':
+			return 'https://www.gnu.org/licenses/license-list.html#CC0';
+		case 'PublicDomain':
+			return 'https://www.gnu.org/licenses/license-list.html#PublicDomain';
+		case 'Unlicense':
+			return 'https://www.gnu.org/licenses/license-list.html#Unlicense';
+		case 'MPL':
+			return 'https://www.gnu.org/licenses/license-list.html#MPL';
+		case 'MPL2':
+			return 'https://www.gnu.org/licenses/license-list.html#MPL-2.0';
+		case 'NCSA':
+			return 'https://www.gnu.org/licenses/license-list.html#NCSA';
+		case 'Zlib':
+			return 'https://www.gnu.org/licenses/license-list.html#ZLib';
+		case 'EPL':
+			return 'https://www.gnu.org/licenses/license-list.html#EPL';
+		case 'EUPL':
+			return 'https://www.gnu.org/licenses/license-list.html#EUPL';
 		default:
 			return null;
 		}
 	}
 	function androidversion($sdkLevel) {
 		switch ($sdkLevel) {
+			case 23: return "6.0";
 			case 22: return "5.1";
 			case 21: return "5.0";
 			case 20: return "4.4W";
@@ -279,6 +305,12 @@ class FDroid
 					case "license":
 						$license=$el;
 						break;
+					case "author":
+						$author=$el;
+						break;
+					case "email":
+						$email=$el;
+						break;
 					case "source":
 						$source=$el;
 						break;
@@ -398,6 +430,11 @@ class FDroid
 				$out.="<p>";
 				if(strlen($web)>0)
 					$out.='<b>Website:</b> <a href="'.$web.'">'.$web.'</a><br />';
+				if(isset($author) && strlen($author)>0)
+					if(isset($email) && strlen($email)>0)
+						$out.='<b>Author(s):</b> <a href="mailto:'.$email.'">'.$author.'</a><br />';
+					else
+						$out.='<b>Author(s):</b> '.$author.'<br />';
 				if(strlen($issues)>0)
 					$out.='<b>Issue Tracker:</b> <a href="'.$issues.'">'.$issues.'</a><br />';
 				if(strlen($source)>0)
@@ -451,7 +488,7 @@ class FDroid
 					$hasabis = isset($apk['nativecode']);
 					if($hasabis) {
 						$abis = str_replace(',', ' ', $apk['nativecode']);
-						$out.="<p>This version uses native code and will only run on: ".$abis."</p>";
+						$out.="<p>This version uses native code and is built for: ".$abis."</p>";
 					}
 
 					// Is this source or binary?
@@ -652,6 +689,8 @@ class FDroid
 		$antifeatureDescription['NonFreeDep']['description'] = 'This application depends on another non-Free application.';
 		$antifeatureDescription['UpstreamNonFree']['name'] = 'Upstream Non-Free';
 		$antifeatureDescription['UpstreamNonFree']['description'] = 'The upstream source code is non-free.';
+		$antifeatureDescription['NonFreeAssets']['name'] = 'Non-Free Assets';
+		$antifeatureDescription['NonFreeAssets']['description'] = 'This application contains non-free assets.';
 
 		if(isset($antifeatureDescription[$antifeature])) {
 			return $antifeatureDescription[$antifeature];
